==> qore-1.4.0.tar.bz2: qore-1.4.0/docs/library/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Programming Language - C/C++ Library", "index.html", [
    [ "Programming with the Qore Library", "index.html", "index" ],
    [ "Embedding Qore Code", "embedding_page.html", [
      [ "Embedding Qore Code", "embedding_page.html#embedding", [
        [ "Initializing and Closing the Qore Library", "embedding_page.html#initializing_and_closing_library", null ],
        [ "Parsing and Running Qore Code", "embedding_page.html#parsing_and_running", null ]
      ] ]
    ] ],
    [ "Qore Builtin Functions", "builtin_functions_page.html", [
      [ "Qore Builtin Functions", "builtin_functions_page.html#builtin_functions", [
        [ "Handling Function Arguments", "builtin_functions_page.html#handling_function_arguments", null ],
        [ "Function Return Value", "builtin_functions_page.html#function_return_value", null ],
        [ "Raising Exceptions in a Function", "builtin_functions_page.html#function_raising_exceptions", null ]
      ] ]
    ] ],
    [ "Implementing Qore Classes", "class_implementation_page.html", [
      [ "Implementing Qore Classes", "class_implementation_page.html#class_implementation", [
        [ "Constructor Methods", "class_implementation_page.html#constructor_methods", null ],
        [ "Copy Methods", "class_implementation_page.html#copy_methods", null ],
        [ "Destructor Methods", "class_implementation_page.html#destructor_methods", null ],
        [ "Regular Class Methods", "class_implementation_page.html#regular_class_methods", null ],
        [ "Static Class Methods", "class_implementation_page.html#static_class_methods", null ],
        [ "Threading Issues in Class Implementation", "class_implementation_page.html#object_threading_issues", null ],
        [ "Implementing Class Hierarchies", "class_implementation_page.html#class_hierarchies", null ]
      ] ]
    ] ],
    [ "Implementing Qore DBI Drivers", "dbi_drivers_page.html", [
      [ "Implementing Qore DBI Drivers", "dbi_drivers_page.html#dbi_drivers", [
        [ "DBI Function Overview", "dbi_drivers_page.html#dbi_function_overview", null ],
        [ "DBI Open Method", "dbi_drivers_page.html#dbi_open", null ],
        [ "DBI Close Method", "dbi_drivers_page.html#dbi_close", null ],
        [ "DBI Select Method", "dbi_drivers_page.html#dbi_select", null ],
        [ "DBI SelectRows Method", "dbi_drivers_page.html#dbi_select_rows", null ],
        [ "DBI Exec Method", "dbi_drivers_page.html#dbi_exec", null ],
        [ "DBI Commit Method", "dbi_drivers_page.html#dbi_commit", null ],
        [ "DBI Rollback Method", "dbi_drivers_page.html#dbi_rollback", null ],
        [ "DBI BeginTransaction Method", "dbi_drivers_page.html#dbi_begin_transaction", null ],
        [ "DBI AbortTransactionStart Method", "dbi_drivers_page.html#dbi_abort_transaction_start", null ],
        [ "DBI GetServerVersion Method", "dbi_drivers_page.html#dbi_get_server_version", null ],
        [ "DBI GetClientVersion Method", "dbi_drivers_page.html#dbi_get_client_version", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_abstract_exception_8h.html",
"_qore_lib_8h.html#a809a408f68fb8ccbaacfc6562567890a",
"class_abstract_call_reference_node.html#a93e057c696b5fd95e29be86acebd0522",
"class_datasource.html#adad749856ca451c26021259e9dabfb50",
"class_opt_locker.html#ac2adcaabf369999862025b196531669c",
"class_qore_debug_program.html#a3e49b2a22b0d23d3667aefcc4159a8e9",
"class_qore_h_t_t_p_client.html#a92123163306c695854f61df937855aad",
"class_qore_namespace_constant_iterator.html",
"class_qore_program.html#a5c86c73ae8b9fac6035d0ec2b4732e54",
"class_qore_socket.html#ac135d0900467fd6db754fea9200e2985",
"class_qore_string_node.html#a29ce949575dbd0628cfb2172cbed98ac",
"class_temp_encoding_helper.html#a5d10492897dc2779672bc830ec2886d4",
"macros-aarch64_8h_source.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.5.0.tar.bz2: qore-1.5.0/docs/library/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore Programming Language - C/C++ Library", "index.html", [
    [ "Programming with the Qore Library", "index.html", "index" ],
    [ "Embedding Qore Code", "embedding_page.html", [
      [ "Embedding Qore Code", "embedding_page.html#embedding", [
        [ "Initializing and Closing the Qore Library", "embedding_page.html#initializing_and_closing_library", null ],
        [ "Parsing and Running Qore Code", "embedding_page.html#parsing_and_running", null ]
      ] ]
    ] ],
    [ "Qore Builtin Functions", "builtin_functions_page.html", [
      [ "Qore Builtin Functions", "builtin_functions_page.html#builtin_functions", [
        [ "Handling Function Arguments", "builtin_functions_page.html#handling_function_arguments", null ],
        [ "Function Return Value", "builtin_functions_page.html#function_return_value", null ],
        [ "Raising Exceptions in a Function", "builtin_functions_page.html#function_raising_exceptions", null ]
      ] ]
    ] ],
    [ "Implementing Qore Classes", "class_implementation_page.html", [
      [ "Implementing Qore Classes", "class_implementation_page.html#class_implementation", [
        [ "Constructor Methods", "class_implementation_page.html#constructor_methods", null ],
        [ "Copy Methods", "class_implementation_page.html#copy_methods", null ],
        [ "Destructor Methods", "class_implementation_page.html#destructor_methods", null ],
        [ "Regular Class Methods", "class_implementation_page.html#regular_class_methods", null ],
        [ "Static Class Methods", "class_implementation_page.html#static_class_methods", null ],
        [ "Threading Issues in Class Implementation", "class_implementation_page.html#object_threading_issues", null ],
        [ "Implementing Class Hierarchies", "class_implementation_page.html#class_hierarchies", null ]
      ] ]
    ] ],
    [ "Implementing Qore DBI Drivers", "dbi_drivers_page.html", [
      [ "Implementing Qore DBI Drivers", "dbi_drivers_page.html#dbi_drivers", [
        [ "DBI Function Overview", "dbi_drivers_page.html#dbi_function_overview", null ],
        [ "DBI Open Method", "dbi_drivers_page.html#dbi_open", null ],
        [ "DBI Close Method", "dbi_drivers_page.html#dbi_close", null ],
        [ "DBI Select Method", "dbi_drivers_page.html#dbi_select", null ],
        [ "DBI SelectRows Method", "dbi_drivers_page.html#dbi_select_rows", null ],
        [ "DBI Exec Method", "dbi_drivers_page.html#dbi_exec", null ],
        [ "DBI Commit Method", "dbi_drivers_page.html#dbi_commit", null ],
        [ "DBI Rollback Method", "dbi_drivers_page.html#dbi_rollback", null ],
        [ "DBI BeginTransaction Method", "dbi_drivers_page.html#dbi_begin_transaction", null ],
        [ "DBI AbortTransactionStart Method", "dbi_drivers_page.html#dbi_abort_transaction_start", null ],
        [ "DBI GetServerVersion Method", "dbi_drivers_page.html#dbi_get_server_version", null ],
        [ "DBI GetClientVersion Method", "dbi_drivers_page.html#dbi_get_client_version", null ]
      ] ]
    ] ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_abstract_exception_8h.html",
"_qore_lib_8h.html#a809a408f68fb8ccbaacfc6562567890a",
"class_abstract_call_reference_node.html#a93e057c696b5fd95e29be86acebd0522",
"class_datasource.html#adad749856ca451c26021259e9dabfb50",
"class_opt_locker.html#ac2adcaabf369999862025b196531669c",
"class_qore_debug_program.html#a3e49b2a22b0d23d3667aefcc4159a8e9",
"class_qore_h_t_t_p_client.html#a92123163306c695854f61df937855aad",
"class_qore_namespace_constant_iterator.html",
"class_qore_program.html#a5c86c73ae8b9fac6035d0ec2b4732e54",
"class_qore_socket.html#ac135d0900467fd6db754fea9200e2985",
"class_qore_string_node.html#a29ce949575dbd0628cfb2172cbed98ac",
"class_temp_encoding_helper.html#a5d10492897dc2779672bc830ec2886d4",
"group___string_concat_decoding.html#gac3efe4d2358f501e2e92585c7c5afb09",
"unionqore__i8__u.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
